unit AlertUnit;

interface

uses
  Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, ExtCtrls, StdCtrls, Buttons, StrUtils, ShellApi, Windows;

type
  TAlertForm = class(TForm)
    TitleLabel: TLabel;
    Timer: TTimer;
    MainBevel: TBevel;
    CloseButtonImage: TImage;
    AlertPanel: TPanel;
    AlertLabel: TLabel;
    procedure CloseButtonClick(Sender: TObject);
    procedure ShowIt;
    procedure HideIt;
    procedure TimerTimer(Sender: TObject);
    procedure CloseButtonImageClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure AlertLabelMouseEnter(Sender: TObject);
    procedure AlertLabelMouseLeave(Sender: TObject);
    procedure FormActivate(Sender: TObject);
    procedure AlertLabelClick(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  AlertForm: TAlertForm;

implementation

uses ConsoleUnit, ConfigUnit;

{$R *.dfm}
Var
    StartX,
    StartY,
    EndX,
    EndY: Integer;

procedure TAlertForm.CloseButtonClick(Sender: TObject);
begin
     AlertForm.HideIt;
end;

procedure TAlertForm.ShowIt;

var I: Integer;

begin
     If Not ConfigForm.Config_EnablePopupAlerts Then Exit;

     AlertForm.Left:=StartX;
     { Ensure that this window is one of the TOP Most Windows in the Desktop }
     Application.NormalizeTopMosts;
     SetWindowPos(AlertForm.Handle, HWND_TOPMOST, 0,0,0,0, SWP_NOACTIVATE+SWP_NOMOVE+SWP_NOSIZE);
     AlertForm.Show;
     I:=StartX;
     Repeat
           Application.ProcessMessages;
           sleep(5);
           AlertForm.Left:=I;
           I:=I-2;
     Until (I = EndX);
     Timer.Enabled:=True;
end;

procedure TAlertForm.HideIt;

var I: Integer;

begin
     AlertForm.Left:=EndX;
     I:=EndX;
     Repeat
           Application.ProcessMessages;
           sleep(5);
           AlertForm.Left:=I;
           I:=I+2;
     Until (I = StartX);
     AlertForm.Hide;
end;

procedure TAlertForm.TimerTimer(Sender: TObject);
begin
     Timer.Enabled:=False;
     AlertForm.HideIt;
end;

procedure TAlertForm.CloseButtonImageClick(Sender: TObject);
begin
     AlertForm.HideIt;
end;

procedure TAlertForm.FormCreate(Sender: TObject);

begin
     StartX:=Screen.Width+15;
     StartY:=Screen.Height-AlertForm.Height-30;
     EndX:=Screen.Width-AlertForm.Width-2;
     EndY:=StartY;
     AlertForm.Left:=StartX;
     AlertForm.Top:=StartY;
end;

procedure TAlertForm.AlertLabelMouseEnter(Sender: TObject);
begin
     AlertLabel.Cursor:=crHandpoint;
     AlertLabel.Font.Style:=[fsUnderline];
end;

procedure TAlertForm.AlertLabelMouseLeave(Sender: TObject);
begin
     AlertLabel.Cursor:=crDefault;
     AlertLabel.Font.Style:=[];
end;

procedure TAlertForm.FormActivate(Sender: TObject);
begin
{    Always on TOP
     SetWindowPos(Handle,
                   HWND_TOPMOST,
                   Left,
                   Top,
                   Width,
                   Height,
                   SWP_NOACTIVATE or SWP_NOMOVE or SWP_NOSIZE);}
end;

procedure TAlertForm.AlertLabelClick(Sender: TObject);
Var AlertStr: String;
begin
     AlertStr:=AnsiUpperCase(AlertLabel.Caption);
     { Open Browser in required Problem }
     {
     Browser=NagiosCGIEdit.Text+NagiosURL_Hosts_Up;}
     If (ConfigForm.Config_NagiosCGI = '') Then
     Begin
          MessageDlg('There are not Nagios CGI URL defined in configuration?', mtInformation, [mbOk], 0);
          Exit;
     end;

     If AnsiContainsStr(AlertStr, 'UP') Then
             ShellExecute(Handle, 'open', PChar(ConfigForm.Config_NagiosCGI+ConfigForm.NagiosCGIURL_Hosts_Up), nil, nil, SW_SHOWNORMAL)
     else If AnsiContainsStr(AlertStr, 'DOWN') Then
             ShellExecute(Handle, 'open', PChar(ConfigForm.Config_NagiosCGI+ConfigForm.NagiosCGIURL_Hosts_Down), nil, nil, SW_SHOWNORMAL)
     else If AnsiContainsStr(AlertStr, 'UNREACHABLE') Then
             ShellExecute(Handle, 'open', PChar(ConfigForm.Config_NagiosCGI+ConfigForm.NagiosCGIURL_Hosts_Unreachable), nil, nil, SW_SHOWNORMAL)
     else If AnsiContainsStr(AlertStr, 'PENDING') Then
             ShellExecute(Handle, 'open', PChar(ConfigForm.Config_NagiosCGI+ConfigForm.NagiosCGIURL_Hosts_Pending), nil, nil, SW_SHOWNORMAL)
     { Services }
     else If AnsiContainsStr(AlertStr, 'OK') Then
             ShellExecute(Handle, 'open', PChar(ConfigForm.Config_NagiosCGI+ConfigForm.NagiosCGIURL_Services_Ok), nil, nil, SW_SHOWNORMAL)
     else If AnsiContainsStr(AlertStr, 'WARNING') Then
             ShellExecute(Handle, 'open', PChar(ConfigForm.Config_NagiosCGI+ConfigForm.NagiosCGIURL_Services_Warning), nil, nil, SW_SHOWNORMAL)
     else If AnsiContainsStr(AlertStr, 'UNKNOWN') Then
             ShellExecute(Handle, 'open', PChar(ConfigForm.Config_NagiosCGI+ConfigForm.NagiosCGIURL_Services_Unknown), nil, nil, SW_SHOWNORMAL)
     else If AnsiContainsStr(AlertStr, 'CRITICAL') Then
             ShellExecute(Handle, 'open', PChar(ConfigForm.Config_NagiosCGI+ConfigForm.NagiosCGIURL_Services_Critical), nil, nil, SW_SHOWNORMAL)
     else If AnsiContainsStr(AlertStr, 'PENDING') Then
             ShellExecute(Handle, 'open', PChar(ConfigForm.Config_NagiosCGI+ConfigForm.NagiosCGIURL_Services_Pending), nil, nil, SW_SHOWNORMAL)
end;

end.

