unit ConfigUnit;

interface

{$IFDEF MSWINDOWS}
uses
  Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, ComCtrls, StdCtrls, ExtCtrls, Mask, IniFiles, StrUtils;
{$ENDIF}
{$IFDEF LINUX}
uses
  Messages, SysUtils, Variants, Classes, QGraphics, Controls, QForms,
  QDialogs, QComCtrls, QStdCtrls, QExtCtrls, QMask, IniFiles;
{$ENDIF}

type
  TConfigForm = class(TForm)
    OkButton: TButton;
    Button2: TButton;
    Panel1: TPanel;
    Label1: TLabel;
    NagiosURLEdit: TEdit;
    NagiosCGIEdit: TEdit;
    NagiosCGILabel: TLabel;
    NagiosAuthCheckBox: TCheckBox;
    UsernameLabel: TLabel;
    NagiosUsernameEdit: TEdit;
    PasswordLabel: TLabel;
    Bevel2: TBevel;
    EnableProxyCheckBox: TCheckBox;
    Label6: TLabel;
    ProxyHostnameEdit: TEdit;
    ProxyPortEdit: TEdit;
    ProxyServerPortLabel: TLabel;
    ProxyAuthCheckBox: TCheckBox;
    Label3: TLabel;
    ProxyUsernameEdit: TEdit;
    Label4: TLabel;
    NagiosPasswordEdit: TMaskEdit;
    ProxyPasswordEdit: TMaskEdit;
    AlertGroupBox: TGroupBox;
    EnablePopupAlertsCheckBox: TCheckBox;
    EnableSoundCheckBox: TCheckBox;
    AutomaticCheckRadioGroup: TRadioGroup;
    CheckIntervalEdit: TEdit;
    CheckIntervalUpDown: TUpDown;
    procedure OkButtonClick(Sender: TObject);
    procedure NagiosAuthCheckBoxClick(Sender: TObject);
    procedure EnableProxyCheckBoxClick(Sender: TObject);
    procedure ProxyAuthCheckBoxClick(Sender: TObject);
    procedure AutomaticCheckRadioGroupClick(Sender: TObject);
    procedure EnableSoundCheckBoxClick(Sender: TObject);
    procedure EnablePopupAlertsCheckBoxClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure FormShow(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
     Config_NagiosURL      : String;
     Config_NagiosCGI      : String;
     Config_NagiosAuth     : Boolean;
     Config_NagiosUsername : String;
     Config_NagiosPassword : String;

     Config_AutomaticCheck    : Integer;
     Config_CheckInterval     : String;

     Config_EnableProxy       : Boolean;
     Config_ProxyHostname     : String;
     Config_ProxyPort         : String;
     Config_ProxyAuth         : Boolean;
     Config_ProxyUsername     : String;
     Config_ProxyPassword     : String;

     Config_EnableSound       : Boolean;
     Config_EnablePopupAlerts : Boolean;
{ NAGIOS URL Links}
      NagiosCGIURL_Hosts_Up         : String;
      NagiosCGIURL_Hosts_Unreachable: String;
      NagiosCGIURL_Hosts_Pending    : String;
      NagiosCGIURL_Hosts_Down       : String;

      NagiosCGIURL_Services_Ok      : String;
      NagiosCGIURL_Services_Warning : String;
      NagiosCGIURL_Services_Unknown : String;
      NagiosCGIURL_Services_Pending : String;
      NagiosCGIURL_Services_Critical: String;
{}
    procedure SetHTTPOptions;
    procedure LoadIniConfigurations(Sender: TObject);
    procedure SaveIniConfigurations(Sender: TObject);
  end;

var
  ConfigForm: TConfigForm;

implementation

uses ConsoleUnit;

{$R *.dfm}

procedure TConfigForm.SetHTTPOptions;
Begin
     If ( (Config_NagiosCGI = '') or (Config_NagiosURL = ''))Then Exit;

     If (Config_NagiosAuth) Then
     Begin
          ConsoleForm.HTTP.Request.Username:=Config_NagiosUsername;
          ConsoleForm.HTTP.Request.Password:=Config_NagiosPassword;
     end;
     If (Config_EnableProxy) Then
     Begin
          ConsoleForm.HTTP.ProxyParams.ProxyServer:=Config_ProxyHostname;
          ConsoleForm.HTTP.ProxyParams.ProxyPort:=StrToIntDef(Config_ProxyPort, 80);
          If (Config_ProxyAuth) Then
          Begin
               ConsoleForm.HTTP.ProxyParams.BasicAuthentication:=True;
               ConsoleForm.HTTP.ProxyParams.ProxyUsername:=Config_ProxyUsername;
               ConsoleForm.HTTP.ProxyParams.ProxyPassword:=Config_ProxyPassword;
          end
          else ConsoleForm.HTTP.ProxyParams.BasicAuthentication:=False;
     end;

     If (Config_AutomaticCheck = 1) Then
     Begin
          ConsoleForm.Timer.Interval:=StrToInt(Config_CheckInterval+'000');
     end;

     ConsoleForm.HTTP.Request.ContentType:='';
end;

procedure TConfigForm.OkButtonClick(Sender: TObject);
begin
     If Not AnsiEndsStr('/', NagiosCGIEdit.Text) Then
        NagiosCGIEdit.Text:=NagiosCGIEdit.Text+'/';
     If Not AnsiEndsStr('/', NagiosURLEdit.Text) Then
        NagiosURLEdit.Text:=NagiosURLEdit.Text+'/';

     Config_NagiosURL:=NagiosURLEdit.Text;
     Config_NagiosCGI:=NagiosCGIEdit.Text;
     Config_NagiosAuth:=NagiosAuthCheckBox.Checked;
     Config_NagiosUsername:=NagiosUsernameEdit.Text;
     Config_NagiosPassword:=NagiosPasswordEdit.Text;

     Config_AutomaticCheck:=AutomaticCheckRadioGroup.ItemIndex;
     Config_CheckInterval:=CheckIntervalEdit.Text;

     Config_EnableProxy:=EnableProxyCheckBox.Checked;
     Config_ProxyHostname:=ProxyHostnameEdit.Text;
     Config_ProxyPort:=ProxyPortEdit.Text;
     Config_ProxyAuth:=ProxyAuthCheckBox.Checked;

     Config_ProxyUsername:=ProxyUsernameEdit.Text;
     Config_ProxyPassword:=ProxyPasswordEdit.Text;

     Config_EnableSound:=EnableSoundCheckBox.Checked;
     Config_EnablePopupAlerts:=EnablePopupAlertsCheckBox.Checked;

     SetHTTPOptions;
end;

procedure TConfigForm.NagiosAuthCheckBoxClick(Sender: TObject);
begin
     If (NagiosAuthCheckBox.State = cbChecked) Then
     Begin
          NagiosUsernameEdit.Enabled:=True;
          NagiosUsernameEdit.Color:=clWindow;
          NagiosPasswordEdit.Enabled:=True;
          NagiosPasswordEdit.Color:=clWindow;
          NagiosUsernameEdit.SetFocus;
     end
     else
     Begin
          NagiosUsernameEdit.Enabled:=False;
          NagiosUsernameEdit.Color:=clBtnFace;
          NagiosPasswordEdit.Enabled:=False;
          NagiosPasswordEdit.Color:=clBtnFace;
     end;
end;

procedure TConfigForm.EnableProxyCheckBoxClick(Sender: TObject);
begin
     If (EnableProxyCheckBox.State = cbChecked) Then
     Begin
          ProxyHostnameEdit.Enabled:=True;
          ProxyHostnameEdit.Color:=clWindow;
          ProxyHostnameEdit.SetFocus;
          ProxyPortEdit.Enabled:=True;
          ProxyPortEdit.Color:=clWindow;
          ProxyAuthCheckBox.Enabled:=True;
          If (ProxyAuthCheckBox.State=cbChecked) Then
          Begin
               ProxyUsernameEdit.Enabled:=True;
               ProxyUsernameEdit.Color:=clWindow;
               ProxyPasswordEdit.Enabled:=True;
               ProxyPasswordEdit.Color:=clWindow;
          end;
     end
     else
     Begin
          ProxyHostnameEdit.Enabled:=False;
          ProxyHostnameEdit.Color:=clBtnFace;
          ProxyPortEdit.Enabled:=False;
          ProxyPortEdit.Color:=clBtnFace;
          ProxyAuthCheckBox.Enabled:=False;
          ProxyUsernameEdit.Enabled:=False;
          ProxyUsernameEdit.Color:=clBtnFace;
          ProxyPasswordEdit.Enabled:=False;
          ProxyPasswordEdit.Color:=clBtnFace;
     end;
end;

procedure TConfigForm.ProxyAuthCheckBoxClick(Sender: TObject);
begin
          If (ProxyAuthCheckBox.State=cbChecked) Then
          Begin
               ProxyUsernameEdit.Enabled:=True;
               ProxyUsernameEdit.Color:=clWindow;
               ProxyPasswordEdit.Enabled:=True;
               ProxyPasswordEdit.Color:=clWindow;
          end
          else
          Begin
               ProxyUsernameEdit.Enabled:=True;
               ProxyUsernameEdit.Color:=clBtnFace;
               ProxyPasswordEdit.Enabled:=True;
               ProxyPasswordEdit.Color:=clBtnFace;
          end;
end;

procedure TConfigForm.AutomaticCheckRadioGroupClick(Sender: TObject);
begin
     If AutomaticCheckRadioGroup.ItemIndex = 1 Then
     Begin
          CheckIntervalEdit.Color:=clWindow;
          CheckIntervalEdit.Enabled:=True;
          CheckIntervalUpDown.Enabled:=True;
          If ConfigForm.Showing Then CheckIntervalEdit.SetFocus;
          ConsoleForm.AutomaticChecksSubMenu.Checked:=True;
          ConsoleForm.AutomaticChecksPopupMenu.Checked:=True;
     end
     else
     Begin
          CheckIntervalEdit.Color:=clBtnFace;
          CheckIntervalEdit.Enabled:=False;
          CheckIntervalUpDown.Enabled:=False;
          ConsoleForm.AutomaticChecksSubMenu.Checked:=False;
          ConsoleForm.AutomaticChecksPopupMenu.Checked:=False;
     end;
end;

procedure TConfigForm.LoadIniConfigurations(Sender: TObject);

Var MyIniFile: TCustomIniFile;

Begin
     MyIniFile:=TIniFile.Create(ExtractFilePath(Application.ExeName)+'ntrayc.ini');

     If MyIniFile.ReadBool('Config', 'AutomaticChecks', False) Then
     Begin
          Config_AutomaticCheck:=1;
          ConsoleForm.AutomaticChecksSubMenu.Checked:=True;
          ConsoleForm.AutomaticChecksPopupMenu.Checked:=True;
     end
     else
     Begin
          Config_AutomaticCheck:=0;
          ConsoleForm.AutomaticChecksSubMenu.Checked:=False;
          ConsoleForm.AutomaticChecksPopupMenu.Checked:=False;
     end;

     Config_CheckInterval:=MyIniFile.ReadString('Nagios', 'CheckInterval', '60');

     Config_NagiosURL:=MyIniFile.ReadString('Nagios', 'NagiosURL', '');
     Config_NagiosCGI:=MyIniFile.ReadString('Nagios', 'NagiosCGI', '');
     Config_NagiosAuth:=MyIniFile.ReadBool('Nagios', 'EnableAuth', False);
     Config_NagiosUsername:=MyIniFile.ReadString('Nagios', 'Username', '');
     Config_NagiosPassword:=MyIniFile.ReadString('Nagios', 'Password', '');

     Config_EnableProxy:=MyIniFile.ReadBool('Proxy', 'Enabled', False);
     Config_ProxyHostname:=MyIniFile.ReadString('Proxy', 'Hostname', '');
     Config_ProxyPort:=MyIniFile.ReadString('Proxy', 'Port', '');

     Config_ProxyAuth:=MyIniFile.ReadBool('Proxy', 'EnableAuth', False);
     Config_ProxyUsername:=MyIniFile.ReadString('Proxy', 'Username', '');
     Config_ProxyPassword:=MyIniFile.ReadString('Proxy', 'Password', '');

     Config_EnableSound:=MyIniFile.ReadBool('Config', 'Sounds', True);
     Config_EnablePopupAlerts:=MyIniFile.ReadBool('Config', 'Alerts', True);

     MyIniFile.Free;

     { Set menu and other options }
     ConsoleForm.Timer.Interval:=StrToInt(Config_CheckInterval+'000');
     If (ConsoleForm.Timer.Interval < 30000) Then
          ConsoleForm.Timer.Interval:=30000;

     ConsoleForm.Timer.Enabled:=(Config_AutomaticCheck = 1);
     NagiosAuthCheckBoxClick(Sender);
     EnablePopupAlertsCheckBoxClick(Sender);
     ProxyAuthCheckBoxClick(Sender);
     EnableProxyCheckBoxClick(Sender);
end;

procedure TConfigForm.SaveIniConfigurations(Sender: TObject);

Var MyIniFile: TCustomIniFile;

Begin

     MyIniFile:=TIniFile.Create(ExtractFilePath(Application.ExeName)+'ntrayc.ini');

     MyIniFile.WriteInteger('Config', 'AutomaticChecks', Config_AutomaticCheck);
     MyIniFile.WriteInteger('Config', 'ChecksInterval', StrToInt(Config_CheckInterval));

     MyIniFile.WriteString('Nagios', 'NagiosURL', Config_NagiosURL);
     MyIniFile.WriteString('Nagios', 'NagiosCGI', Config_NagiosCGI);
     MyIniFile.WriteBool('Nagios', 'EnableAuth', Config_NagiosAuth);
     MyIniFile.WriteString('Nagios', 'Username', Config_NagiosUsername);
     MyIniFile.WriteString('Nagios', 'Password', Config_NagiosPassword);

     MyIniFile.WriteBool('Proxy', 'Enabled', Config_EnableProxy);
     MyIniFile.WriteString('Proxy', 'Hostname', Config_ProxyHostname);
     MyIniFile.WriteString('Proxy', 'Port', Config_ProxyPort);

     MyIniFile.WriteBool('Proxy', 'EnableAuth', Config_ProxyAuth);
     MyIniFile.WriteString('Proxy', 'Username', Config_ProxyUsername);
     MyIniFile.WriteString('Proxy', 'Password', Config_ProxyPassword);

     MyIniFile.WriteBool('Config', 'Sounds', Config_EnableSound);
     MyIniFile.WriteBool('Config', 'Alerts', Config_EnablePopupAlerts);
     MyIniFile.Free;
end;


procedure TConfigForm.EnableSoundCheckBoxClick(Sender: TObject);
begin
     Config_EnableSound:=EnableSoundCheckBox.Checked;
end;

procedure TConfigForm.EnablePopupAlertsCheckBoxClick(Sender: TObject);
begin
     Config_EnablePopupAlerts:=EnablePopupAlertsCheckBox.Checked;
     ConsoleForm.EnableAlertWindowPopupMenu.Checked:=EnablePopupAlertsCheckBox.Checked;
end;


procedure TConfigForm.FormCreate(Sender: TObject);
begin
{ Set Nagios URL Links }
     NagiosCGIURL_Hosts_Up         := 'status.cgi?host=all&style=hostdetail&hoststatustypes=2';
     NagiosCGIURL_Hosts_Unreachable:= 'status.cgi?host=all&style=hostdetail&hoststatustypes=8';
     NagiosCGIURL_Hosts_Pending    := 'status.cgi?host=all&style=hostdetail&hoststatustypes=1';
     NagiosCGIURL_Hosts_Down       := 'status.cgi?host=all&style=hostdetail&hoststatustypes=4';

     NagiosCGIURL_Services_Ok      := 'status.cgi?host=all&style=detail&servicestatustypes=2';
     NagiosCGIURL_Services_Warning := 'status.cgi?host=all&style=detail&servicestatustypes=4';
     NagiosCGIURL_Services_Unknown := 'status.cgi?host=all&style=detail&servicestatustypes=8';
     NagiosCGIURL_Services_Pending := 'status.cgi?host=all&style=detail&servicestatustypes=1';
     NagiosCGIURL_Services_Critical:= 'status.cgi?host=all&style=detail&servicestatustypes=16';
{}
     LoadIniConfigurations(Sender);
end;

procedure TConfigForm.FormDestroy(Sender: TObject);
begin
     SaveIniConfigurations(Sender);
end;

procedure TConfigForm.FormShow(Sender: TObject);
begin
     NagiosURLEdit.Text:=Config_NagiosURL;
     NagiosCGIEdit.Text:=Config_NagiosCGI;
     NagiosAuthCheckBox.Checked:=Config_NagiosAuth;
     NagiosUsernameEdit.Text:=Config_NagiosUsername;
     NagiosPasswordEdit.Text:=Config_NagiosPassword;

     AutomaticCheckRadioGroup.ItemIndex:=Config_AutomaticCheck;
     CheckIntervalEdit.Text:=Config_CheckInterval;

     EnableProxyCheckBox.Checked:=Config_EnableProxy;
     ProxyHostnameEdit.Text:=Config_ProxyHostname;
     ProxyPortEdit.Text:=Config_ProxyPort;
     ProxyAuthCheckBox.Checked:=Config_ProxyAuth;

     ProxyUsernameEdit.Text:=Config_ProxyUsername;
     ProxyPasswordEdit.Text:=Config_ProxyPassword;

     EnableSoundCheckBox.Checked:=Config_EnableSound;
     EnablePopupAlertsCheckBox.Checked:=Config_EnablePopupAlerts;
end;

end.
