unit ConsoleUnit;

interface

uses
  Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, StdCtrls, Menus, ImgList, ComCtrls, IdBaseComponent,
  IdComponent, IdTCPConnection, IdTCPClient, IdHTTP, IdAntiFreezeBase,
  IdAntiFreeze, ExtCtrls, IdIntercept, IdLogBase, IdLogDebug, HTMLUnit,
  {}
  Windows, ShellApi, Types, IdIOHandler, IdIOHandlerSocket, IdSSLOpenSSL;


Const
  WM_ICONTRAY = WM_USER + 1;

type
  TConsoleForm = class(TForm)
    MainMenu: TMainMenu;
    ConsoleMenu: TMenuItem;
    CheckNowSubMenu: TMenuItem;
    ConfigSubMenu: TMenuItem;
    HelpMenu: TMenuItem;
    AboutMenu: TMenuItem;
    ExitMenu: TMenuItem;
    HostImageList: TImageList;
    HTTP: TIdHTTP;
    IdAntiFreeze: TIdAntiFreeze;
    N1: TMenuItem;
    N2: TMenuItem;
    StatusBar: TStatusBar;
    Timer: TTimer;
    AutomaticChecksSubMenu: TMenuItem;
    DebugMenu: TMenuItem;
    DebugWindowMenuItem: TMenuItem;
    PageControl: TPageControl;
    StatusSummaryTabSheet: TTabSheet;
    StatusOverviewTabSheet: TTabSheet;
    AllProblemsTabSheet: TTabSheet;
    StatusListView: TListView;
    ListView1: TListView;
    QuickstatsTabSheet: TTabSheet;
    QuickStatsHostsListView: TListView;
    QuickStatsServicesListView: TListView;
    ServiceImageList: TImageList;
    HostGroupsComboBox: TComboBox;
    HostgroupsLabel: TLabel;
    OpenNagiosSubMenu: TMenuItem;
    TrayPopupMenu: TPopupMenu;
    CheckNowPopupMenu: TMenuItem;
    AutomaticChecksPopupMenu: TMenuItem;
    N4: TMenuItem;
    OpenNagiosPopupMenu: TMenuItem;
    ConfigPopupMenu: TMenuItem;
    N6: TMenuItem;
    ExitPopupMenu: TMenuItem;
    EnableAlertWindowPopupMenu: TMenuItem;
    IdSSLIOHandlerSocket1: TIdSSLIOHandlerSocket;
    N3: TMenuItem;
    OpenConsolePopupMenu: TMenuItem;
    N7: TMenuItem;
    FirstTimeTimer: TTimer;
    N5: TMenuItem;
    LogListBox: TListBox;
    ShowAllProblemsPageControl: TPageControl;
    ProblemsTabSheet: TTabSheet;
    UnhandledProblemsTabSheet: TTabSheet;
    ListView2: TListView;
    ListView3: TListView;
    UnhandledHostProblemsListView: TListView;
    UnhandledServiceProblemsListView: TListView;
    procedure AboutMenuClick(Sender: TObject);
    procedure CheckNow(Sender: TObject);
    procedure ConfigSubMenuClick(Sender: TObject);
    procedure CheckNowSubMenuClick(Sender: TObject);
    procedure ExitMenuClick(Sender: TObject);
    procedure TimerTimer(Sender: TObject);
    procedure AutomaticChecksSubMenuClick(Sender: TObject);
    procedure FormShow(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure DebugWindowMenuItemClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
    procedure OpenNagiosSubMenuClick(Sender: TObject);
    procedure HideConsoleSubMenuClick(Sender: TObject);
    procedure EnableAlertWindowPopupMenuClick(Sender: TObject);
    procedure OpenConsolePopupMenuClick(Sender: TObject);
    procedure FirstTimeTimerTimer(Sender: TObject);
  private
    { Private declarations }
    TimerInterval, Status: String;
    LastUpdated: String;
    NagiosOutput: TStringList;
    FirstX: Integer;
    {}
    TrayIconData: NotifyIconData;
    Hosts_Up,
    Hosts_Down,
    Hosts_Unreachable,
    Hosts_Pending: Integer;
    {}
    Service_Ok,
    Service_Warning,
    Service_Unknown,
    Service_Critical,
    Service_Pending: Integer;
{    Memo: TCustomMemo;}
    procedure UpdateSystrayIcon;
    procedure ProcessStatusInfo;
    procedure ParseNagiosOutput(NagiosOutput: TStrings);
    procedure ParseNagiosQuickStats(NagiosOutput: TStrings);
    procedure ParseNagiosStatusSummary(NagiosOutput: TStrings);
    procedure GetNagiosQuickStats(Sender: TObject);
    procedure GetNagiosStatusSummary(Sender: TObject);
  public
    { Public declarations }
    procedure TrayMessage(var Msg: TMessage); message WM_ICONTRAY;
  end;

var
  ConsoleForm: TConsoleForm;

implementation

uses AboutUnit, ConfigUnit, StrUtils, DebugUnit, AlertUnit;

{$R *.dfm}

const URL_QuickStats: string = '/statuswml.cgi?style=quickstats';
      URL_Summary   : string = '/status.cgi?hostgroup=all&style=summary';
      URL_Overview  : string = '/status.cgi?hostgroup=all&style=overview';

      AlertColor_Hosts_Up         : TColor = $00DDFFFF;
      AlertColor_Hosts_Unreachable: TColor = $0046D6FF;
      AlertColor_Hosts_Pending    : TColor = $00DDFFFF;
      AlertColor_Hosts_Down       : TColor = $004242FF;

      AlertColor_Services_Ok      : TColor = $00DDFFFF;
      AlertColor_Services_Warning : TColor = $0046D6FF;
      AlertColor_Services_Unknown : TColor = $00DDFFFF;
      AlertColor_Services_Pending : TColor = $00DDFFFF;
      AlertColor_Services_Critical: TColor = $004242FF;


procedure TConsoleForm.ExitMenuClick(Sender: TObject);
begin
     Application.Terminate;
end;

procedure TConsoleForm.AboutMenuClick(Sender: TObject);
begin
     AboutForm.ShowModal;
end;

procedure TConsoleForm.ConfigSubMenuClick(Sender: TObject);
begin
     ConfigForm.ShowModal;
end;

procedure TConsoleForm.ProcessStatusInfo;
begin
     {Hosts}
     if (Hosts_Unreachable > 0) Then
     Begin
          AlertForm.AlertLabel.Font.Color:=clBlack;
          AlertForm.AlertPanel.Color:=AlertColor_Hosts_Unreachable;
          HostImageList.GetIcon(1, Application.Icon);

          if (Status = 'All Ok') Then
             Status:=IntToStr(Hosts_Unreachable)+' Hosts Unreachable'
          else
              Status:=Status+#13+IntToStr(Hosts_Unreachable)+' Hosts Unreachable';
     end;
     if (Hosts_Down > 0) Then
     Begin
          AlertForm.AlertLabel.Font.Color:=clWhite;
          AlertForm.AlertPanel.Color:=AlertColor_Hosts_Down;
          HostImageList.GetIcon(2, Application.Icon);

          if (Status = 'All Ok') Then
             Status:=IntToStr(Hosts_Down)+' Hosts Down'
          else
             Status:=Status+#13+IntToStr(Hosts_Down)+' Hosts Down';
     end;
     if (Hosts_Pending > 0) Then
     Begin
          AlertForm.AlertLabel.Font.Color:=clBlack;
          AlertForm.AlertPanel.Color:=AlertColor_Hosts_Pending;
          HostImageList.GetIcon(0, Application.Icon);

          if (Status = 'All Ok') Then
             Status:=IntToStr(Hosts_Down)+' Hosts Pending'
          else
             Status:=Status+#13+IntToStr(Hosts_Pending)+' Hosts Pending';
     end;

     {Services}
     if (Service_Unknown > 0) Then
     Begin
          AlertForm.AlertLabel.Font.Color:=clBlack;
          AlertForm.AlertPanel.Color:=AlertColor_Services_Unknown;
          ServiceImageList.GetIcon(3, Application.Icon);

          if (Status = 'All Ok') Then
             Status:=IntToStr(Service_Unknown)+' Services Unknown'
          else
             Status:=Status+#13+IntToStr(Service_Unknown)+' Services Unknown'
     end;
     if (Service_Warning > 0) Then
     Begin
          AlertForm.AlertLabel.Font.Color:=clBlack;
          AlertForm.AlertPanel.Color:=AlertColor_Services_Warning;
          ServiceImageList.GetIcon(1, Application.Icon);

          if (Status = 'All Ok') Then
             Status:=IntToStr(Service_Warning)+' Services Warning'
          else
             Status:=Status+#13+IntToStr(Service_Warning)+' Services Warning'
     end;
     if (Service_Critical > 0) Then
     Begin
          AlertForm.AlertLabel.Font.Color:=clWhite;
          AlertForm.AlertPanel.Color:=AlertColor_Services_Critical;
          ServiceImageList.GetIcon(2, Application.Icon);

          if (Status = 'All Ok') Then
             Status:=IntToStr(Service_Critical)+' Services Critical'
          else
             Status:=Status+#13+IntToStr(Service_Critical)+' Services Critical'
     end;
     if (Service_Pending > 0) Then
     Begin
          AlertForm.AlertLabel.Font.Color:=clBlack;
          AlertForm.AlertPanel.Color:=AlertColor_Services_Pending;
          HostImageList.GetIcon(4, Application.Icon);

          if (Status = 'All Ok') Then
             Status:=IntToStr(Service_Pending)+' Services Pending'
          else
             Status:=Status+#13+IntToStr(Service_Pending)+' Services Pending';
     end;

     If (Status = 'All Ok') Then
     Begin
          AlertForm.AlertLabel.Font.Color:=clBlack;
          AlertForm.AlertPanel.Color:=AlertColor_Hosts_Up;
          ServiceImageList.GetIcon(0, Application.Icon);
     end;

     AlertForm.AlertLabel.Caption:=Status;
     StatusBar.Panels.Items[1].Text:='Global Status: '+Status;
     If (Status <> 'All Ok') Then
     Begin
          Application.Title:='Nagios Tray Clone - Status: '+Status;
          AlertForm.ShowIt;
     end
     else Application.Title:='Nagios Tray Clone - Status: Ok';
end;

procedure TConsoleForm.CheckNow(Sender: TObject);
Var TimeStr: String;
begin
     { Get User Defined Values in Memory }
     ConfigForm.SetHTTPOptions;
     {}
     TimeStr:=DateTimeToStr(Now);
     StatusListView.Cursor:=crHourGlass;
     NagiosOutput.Clear;
     { Ensure that the log doesn't get beyond 100 lines }
     If (LogListBox.Items.Count > 100) Then
        LogListBox.ITems.Delete(0);
     LogListBox.Items.Add(TimeStr+': Getting Nagios Status...');
     LogListBox.Update;
     GetNagiosQuickStats(Sender);
{     GetNagiosStatusSummary(Sender);}
     ProcessStatusInfo;
     UpdateSystrayIcon;

     If (LogListBox.Items.Count > 1)Then
          LogListBox.Items.Delete(LogListBox.Items.Count-1);
     LogListBox.Items.Add(TimeStr+': '+Status);
{     LogListBox.ScrollBy(0, 100);}
end;


procedure TConsoleForm.CheckNowSubMenuClick(Sender: TObject);
begin
     { If Timer is enabled, reset it to restart countdown }
     If Timer.Enabled Then
     Begin
          Timer.Enabled:=False;
          Timer.Enabled:=True;
     end;
     CheckNow(Sender);
end;

procedure TConsoleForm.ParseNagiosOutput(NagiosOutput: TStrings);

Const HostsStatusTableCount: Integer = 12;

Var A, Interval, I: Integer;
    Item: TListItem;

Begin
     StatusListView.Items.Clear;
     {}
     For I:=0 to NagiosOutput.Count-1 do
     Begin
          If AnsiContainsStr(NagiosOutput.Strings[I], 'Last Updated: ') Then
          Begin
               {Example line: Last Updated: Thu Nov 21 19:28:30 WET 2002<br> }
               LastUpdated:=Copy(NagiosOutput.Strings[I], 15, 28);
          end;
          If AnsiContainsStr(NagiosOutput.Strings[I], 'Updated every ') Then
          Begin
               { Example line: Updated every 90 seconds<br> }
               TimerInterval:=Copy(NagiosOutput.Strings[I], 15, 3); {<br>}
               If (TimerInterval[3] = ' ') Then Copy(TimerInterval, 1, 1);
               If (TimerInterval[4] = ' ') Then Copy(TimerInterval, 1, 2);
               Interval:=StrToIntDef(TimerInterval, 60);
               Timer.Interval:=(Interval * 1000);
          end;

          If AnsiContainsStr(NagiosOutput.Strings[I], 'last updated') Then
          Begin
               Status:='Good';
               HostImageList.GetIcon(0, Application.Icon);
          end;
          If AnsiContainsStr(NagiosOutput.Strings[I], 'WARNING') Then
          Begin
               Status:='WARNING';
               HostImageList.GetIcon(1, Application.Icon);
          end;
          If AnsiContainsStr(NagiosOutput.Strings[I], 'CRITICAL') Then
          Begin
               Status:='CRITICAL';
               HostImageList.GetIcon(2, Application.Icon);
          end;
     end;
     I:=0;
     A:=0;
{     Repeat
          If (AnsiLeftStr(UpperCase(Memo.Lines.Strings[I]), 6) = '<TABLE') Then Inc(A);
          Inc(I);
     Until (A = HostsStatusTableCount);}
     I:=I+4;
     Repeat
           Item:=StatusListView.Items.Add;
           Item.Caption:=ExtractURLCaption(ExtractURL(NagiosOutput.Strings[I]));
           Inc(I);
     Until (I=NagiosOutput.Count-1);
     StatusBar.Panels.Items[0].Text:='Update Interval: '+TimerInterval;
     StatusBar.Panels.Items[1].Text:='Status: '+Status;
     StatusBar.Update;

     If (LogListBox.Items.Count>0) Then
        LogListBox.Items.Strings[LogListBox.Items.Count-1]:='Updated:'+LastUpdated+', Update Interval: '+TimerInterval+', Status: '+Status
     else LogListBox.Items.Add('Updated:'+LastUpdated+', Update Interval: '+TimerInterval+', Status: '+Status);

     LogListBox.Selected[LogListBox.Count-1]:=True
end;


procedure TConsoleForm.GetNagiosQuickStats(Sender: TObject);

var Stream1: TMemoryStream;

Begin
   try
  {      Stream1:=TMemoryStream.Create;}
      ConfigForm.SetHTTPOptions;
{      NagiosOutput.Text:=HTTP.Get(ConfigForm.Config_NagiosCGI+URL_QuickStats, Stream1);}
      NagiosOutput.Text:=HTTP.Get(ConfigForm.Config_NagiosCGI+URL_QuickStats);
{      Stream1.Memory}
  finally
     StatusListView.Cursor:=crDefault;
     ParseNagiosQuickStats(NagiosOutput);
{     Stream1.Destroy;}
  end;
  {DEBUG window}
     DebugForm.QuickstatsDebugMemo.Clear;
     DebugForm.QuickstatsDebugMemo.Lines.Text:=NagiosOutput.Text;
end;

procedure TConsoleForm.ParseNagiosQuickStats(NagiosOutput: TStrings);

var H, S, N, HostsTotal: Integer;
    Item: TListItem;


begin
     Status:='All Ok';
     Hosts_Up:=0;
     Hosts_Down:=0;
     Hosts_Unreachable:=0;
     Hosts_Pending:=0;
     For H:=0 to NagiosOutput.Count-1 do
     Begin
          { Hosts }
          If AnsiContainsStr(NagiosOutput.Strings[H], 'UP') Then
          Begin
               Item:=QuickStatsHostsListView.Items.Item[0];
               N:=AnsiPos(' UP', UpperCase(NagiosOutput.Strings[H]))-1; //FIXME
               Item.Caption:=Copy(NagiosOutput.Strings[H], 1, N)+' Up';
               Hosts_Up:=StrToInt(Copy(NagiosOutput.Strings[H], 1, N));
          end
          else If AnsiContainsStr(NagiosOutput.Strings[H], 'DOWN') Then
          Begin
               Item:=QuickStatsHostsListView.Items.Item[1];
               N:=AnsiPos(' DOWN', UpperCase(NagiosOutput.Strings[H]))-1;
               Item.Caption:=Copy(NagiosOutput.Strings[H], 1, N)+' Down';
               Hosts_Down:=StrToInt(Copy(NagiosOutput.Strings[H], 1, N));
          end
          else If AnsiContainsStr(NagiosOutput.Strings[H], 'UNREACHABLE') Then
          Begin
               Item:=QuickStatsHostsListView.Items.Item[2];
               N:=AnsiPos(' UNREACHABLE', UpperCase(NagiosOutput.Strings[H]))-1;
               Item.Caption:=Copy(NagiosOutput.Strings[H], 1, N)+' Unreachable';
               Hosts_Unreachable:=StrToInt(Copy(NagiosOutput.Strings[H], 1, N));
          end
          else If AnsiContainsStr(NagiosOutput.Strings[H], 'PENDING') Then
          Begin
               Item:=QuickStatsHostsListView.Items.Item[3];
               N:=AnsiPos(' PENDING', UpperCase(NagiosOutput.Strings[H]))-1;
               Item.Caption:=Copy(NagiosOutput.Strings[H], 1, N)+' Pending';
               Hosts_Pending:=StrToInt(Copy(NagiosOutput.Strings[H], 1, N));
               Break;
          end;
     end;
     { Services }
     Service_Ok:=0;
     Service_Warning:=0;
     Service_Unknown:=0;
     Service_Critical:=0;
     Service_Pending:=0;
     For S:=H to NagiosOutput.Count-1 do
     Begin
          { Hosts }
          If AnsiContainsStr(NagiosOutput.Strings[S], 'OK') Then
          Begin
               Item:=QuickStatsServicesListView.Items.Item[0];
               N:=AnsiPos(' OK', UpperCase(NagiosOutput.Strings[S]))-1;
               Item.Caption:=Copy(NagiosOutput.Strings[S], 1, N)+' Ok';
               Service_Ok:=StrToInt(Copy(NagiosOutput.Strings[S], 1, N));
          end
          else If AnsiContainsStr(NagiosOutput.Strings[S], 'WARNING') Then
          Begin
               Item:=QuickStatsServicesListView.Items.Item[1];
               N:=AnsiPos(' WARNING', UpperCase(NagiosOutput.Strings[S]))-1;
               Item.Caption:=Copy(NagiosOutput.Strings[S], 1, N)+' Warning';
               Service_Warning:=StrToInt(Copy(NagiosOutput.Strings[S], 1, N));
          end
          else If AnsiContainsStr(NagiosOutput.Strings[S], 'UNKNOWN') Then
          Begin
               Item:=QuickStatsServicesListView.Items.Item[2];
               N:=AnsiPos(' UNKNOWN', UpperCase(NagiosOutput.Strings[S]))-1;
               Item.Caption:=Copy(NagiosOutput.Strings[S], 1, N)+' Unknown';
               Service_Unknown:=StrToInt(Copy(NagiosOutput.Strings[S], 1, N));
          end
          else If AnsiContainsStr(NagiosOutput.Strings[S], 'CRITICAL') Then
          Begin
               Item:=QuickStatsServicesListView.Items.Item[3];
               N:=AnsiPos(' CRITICAL', UpperCase(NagiosOutput.Strings[S]))-1;
               Item.Caption:=Copy(NagiosOutput.Strings[S], 1, N)+' Critical';
               Service_Critical:=StrToInt(Copy(NagiosOutput.Strings[S], 1, N));
          end
          else If AnsiContainsStr(NagiosOutput.Strings[S], 'PENDING') Then
          Begin
               Item:=QuickStatsServicesListView.Items.Item[4];
               N:=AnsiPos(' PENDING', UpperCase(NagiosOutput.Strings[S]))-1;
               Item.Caption:=Copy(NagiosOutput.Strings[S], 1, N)+' Pending';
               Service_Pending:=StrToInt(Copy(NagiosOutput.Strings[S], 1, N));
          end;
     end;

end;


procedure TConsoleForm.GetNagiosStatusSummary(Sender: TObject);

Begin
   try
      ConfigForm.SetHTTPOptions;
      NagiosOutput.Text:=HTTP.Get(ConfigForm.Config_NagiosCGI+URL_Summary);
  finally
     StatusListView.Cursor:=crDefault;
     ParseNagiosStatusSummary(NagiosOutput);
  end;
  {DEBUG window}
     DebugForm.StatusSummaryDebugMemo.Clear;
     DebugForm.StatusSummaryDebugMemo.Lines.Text:=NagiosOutput.Text;
end;

procedure TConsoleForm.ParseNagiosStatusSummary(NagiosOutput: TStrings);

var I, H, S, N, HostsTotal: Integer;
    Item: TListItem;
    TmpStr: String;

begin
     TmpStr:='';
     HostGroupsComboBox.Items.Clear;
   { Nagios Hostgroups only start from the 10th line of the statuswml.cgi output }
     I:=9;
     While (I < NagiosOutput.Count-1) do
     Begin
          TmpStr:=AnsiReplaceText(NagiosOutput.Strings[I], '<b><anchor title=''', '');

          TmpStr:=Copy(TmpStr, 0, PosEx('''>', TmpStr, AnsiPos('''>', TmpStr)));
          HostGroupsComboBox.Items.Add(TmpStr);

{               Item:=QuickStatsServicesListView.Items.Item[4];
               N:=AnsiPos(' PENDING', UpperCase(NagiosOutput.Strings[S]))-1;
               Item.Caption:=Copy(NagiosOutput.Strings[S], 1, N)+' Pending';
          end;}
          I:=I+6;
     end;
end;


procedure TConsoleForm.TimerTimer(Sender: TObject);
begin
     // This is only to make it work for the first time,
     // then the real values are passed to Timer
{     ConsoleForm.Timer.Interval:=StrToInt(ConfigForm.Config_CheckInterval);
     If (ConsoleForm.Timer.Interval < 30000) Then
        ConsoleForm.Timer.Interval:=30000;

     If (ConfigForm.Config_AutomaticCheck = 1) Then
        ConsoleForm.Timer.Enabled:=True
     else
        ConsoleForm.Timer.Enabled:=False;
}
     {2000}
     CheckNowSubMenuClick(Sender);
end;

procedure TConsoleForm.AutomaticChecksSubMenuClick(Sender: TObject);
begin
     AutomaticChecksSubMenu.Checked:=Not AutomaticChecksSubMenu.Checked;
     AutomaticChecksPopupMenu.Checked:=Not AutomaticChecksPopupMenu.Checked;
     Timer.Enabled:=AutomaticChecksSubMenu.Checked;

     If AutomaticChecksSubMenu.Checked Then
     Begin
          ConfigForm.Config_AutomaticCheck:=1;

          ConfigForm.AutomaticCheckRadioGroup.ItemIndex:=1;

          ConfigForm.CheckIntervalEdit.Color:=clWindow;
          ConfigForm.CheckIntervalEdit.Enabled:=True;
          ConfigForm.CheckIntervalUpDown.Enabled:=True;
     end
     else
     Begin
          ConfigForm.Config_AutomaticCheck:=0;

          ConfigForm.AutomaticCheckRadioGroup.ItemIndex:=0;

          ConfigForm.CheckIntervalEdit.Color:=clBtnFace;
          ConfigForm.CheckIntervalEdit.Enabled:=False;
          ConfigForm.CheckIntervalUpDown.Enabled:=False;
     end;
end;

procedure TConsoleForm.FormShow(Sender: TObject);
begin
     { Ensure that this window is a onTOP window }
     Application.NormalizeTopMosts;
     SetWindowPos(ConsoleForm.Handle, HWND_TOP, 0,0,0,0, SWP_NOACTIVATE+SWP_NOMOVE+SWP_NOSIZE);

     StatusBar.Panels.Items[0].Text:='Update Interval: '+ConfigForm.Config_CheckInterval;
     DebugMenu.Visible:=(ParamStr(1) = '-debug');
end;

procedure TConsoleForm.FormDestroy(Sender: TObject);
begin
     NagiosOutput.Destroy;
     Shell_NotifyIcon(NIM_DELETE, @TrayIconData);
end;

procedure TConsoleForm.DebugWindowMenuItemClick(Sender: TObject);
begin
     If (DebugWindowMenuItem.Checked) Then
        DebugForm.Show
     else
        DebugForm.Hide;
end;

Procedure TConsoleForm.TrayMessage(var Msg: TMessage);

Var P: TPoint;

Begin
     Case Msg.lParam Of
         WM_RBUTTONDOWN: Begin
                              SetForegroundWindow(Handle);
                              GetCursorPos(p);
                              TrayPopupMenu.Popup(p.x, p.y);
                              PostMessage(Handle, WM_NULL, 0, 0);
                          end;
          WM_LBUTTONDOWN: Begin
                              SetForegroundWindow(Handle);
                              If (ConsoleForm.Visible) Then
                                 ConsoleForm.Hide
                              else
                                 ConsoleForm.Show;
                         end;
     end;
end;


procedure TConsoleForm.UpdateSystrayIcon;
begin
    with TrayIconData do
    Begin
         cbSize:=SizeOf(TrayIconData);
         Wnd:=Handle;
         uID:=0;
         uFlags:=NIF_MESSAGE + NIF_ICON + NIF_TIP;
         uCallbackMessage := WM_ICONTRAY;
         hIcon:=Application.Icon.Handle;
         StrPCopy(szTip, Application.Title);
    end;
    Shell_NotifyIcon(NIM_MODIFY, @TrayIconData); // "NIM_ADD" adds an icon to the Tray area. The other two possible values, NIM_DELETE and NIM_MODIFY
end;

procedure TConsoleForm.FormCreate(Sender: TObject);
begin
     FirstX:=ConsoleForm.Left;
     ConsoleForm.Left:=9000;
     Status:='';
     NagiosOutput:=TStringList.Create;
     SetWindowLong(Application.Handle, GWL_EXSTYLE, WS_EX_TOOLWINDOW);
{     SetWindowLong(Application.Handle, GWL_EXSTYLE, WS_EX_ICON_ID);}
    with TrayIconData do
    Begin
         cbSize:=SizeOf(TrayIconData);
         Wnd:=Handle;
         uID:=0;
         uFlags:=NIF_MESSAGE + NIF_ICON + NIF_TIP;
         uCallbackMessage := WM_ICONTRAY;
         hIcon:=Application.Icon.Handle;
         StrPCopy(szTip, Application.Title);
    end;
    Shell_NotifyIcon(NIM_ADD, @TrayIconData);

     {NIM_ADD,NIM_DELETE,NIM_MODIFY - NOTIFYICONDATA}
{  C++
NOTIFYICONDATA info;
    memset(&info,0,sizeof(info));
    info.cbSize          =sizeof(info) ;
    info.hWnd            =Handle; // form handle gets notification message
    info.uID             =WM_TRAY_ICON_ID; // id of icon - passed back in wParam of message
    info.uCallbackMessage=WM_TRAY_ICON_MESSAGE; // our notification message
    info.hIcon           =hIcon; // icon to display
    strncpy (info.szTip,tipText,sizeof(info.szTip)); // set tool tip text
    info.szTip[sizeof(info.szTip)-1]='0';
    info.uFlags          =NIF_MESSAGE | NIF_ICON | NIF_TIP ; // indicate modifications
    Shell_NotifyIcon(NIM_ADD,&info) ; // add it
}
end;

procedure TConsoleForm.FormClose(Sender: TObject;
  var Action: TCloseAction);
begin
     Action:=caNone;
     ConsoleForm.Hide;
end;

procedure TConsoleForm.OpenNagiosSubMenuClick(Sender: TObject);
begin
     If (ConfigForm.Config_NagiosURL <> '') Then
        ShellExecute(Handle, 'open', PChar(ConfigForm.Config_NagiosURL), nil, nil, SW_SHOWNORMAL)
     else
         MessageDlg('There are not Nagios URL defined in configuration?', mtInformation, [mbOk], 0);
end;

procedure TConsoleForm.HideConsoleSubMenuClick(Sender: TObject);
begin
     ConsoleForm.Hide;
end;

procedure TConsoleForm.EnableAlertWindowPopupMenuClick(Sender: TObject);
begin
     ConfigForm.EnablePopupAlertsCheckBox.Checked:=EnableAlertWindowPopupMenu.Checked;
     ConfigForm.Config_EnablePopupAlerts:=EnableAlertWindowPopupMenu.Checked
end;

procedure TConsoleForm.OpenConsolePopupMenuClick(Sender: TObject);
begin
     ConsoleForm.Show;
end;

procedure TConsoleForm.FirstTimeTimerTimer(Sender: TObject);
begin
     FirstTimeTimer.Enabled:=False;
     if (ConfigForm.Config_AutomaticCheck = 1) Then
        CheckNowSubMenuClick(Sender);
     ConsoleForm.Hide;
     ConsoleForm.Left:=FirstX;
{     ConfigForm.SetHTTPOptions;
     CheckNowSubMenuClick(Sender);}
end;

end.


{
TABLE = 12

<tr CLASS='statusEven'><td CLASS='statusEven'>
<a HREF='status.cgi?hostgroup=DHCP+Servers&style=overview'>DHCPServers</a> (<a HREF='extinfo.cgi?type=5&hostgroup=DHCP+Servers'>DHCP Servers</a>)</td><td CLASS='statusEven' ALIGN=CENTER VALIGN=CENTER><table BORDER=0>

<tr><td CLASS='miniStatusUP'><a HREF='status.cgi?hostgroup=DHCP+Servers&style=detail&&hoststatustypes=2&hostprops=0'>16 UP</a></td></tr>
</table>
</td><td CLASS='statusEven' ALIGN=CENTER VALIGN=CENTER><table BORDER=0>
<tr><td CLASS='miniStatusOK'><a HREF='status.cgi?hostgroup=DHCP+Servers&style=detail&&servicestatustypes=6&hoststatustypes=15&serviceprops=0&hostprops=0'>42 OK</a></td></tr>
<tr><td CLASS='miniStatusCRITICAL'><a HREF='status.cgi?hostgroup=DHCP+Servers&style=detail&servicestatustypes=224&hoststatustypes=15&serviceprops=0&hostprops=0'>2 CRITICAL</a></td></tr>
</table>
</td></tr>
-------------------------------------------------------
Application.Initialize;
  MyStyle:=GetWindowLong(Application.Handle,GWL_EXSTYLE);
  SetWindowLong(Application.Handle,GWL_EXSTYLE,MyStyle or WS_EX_WINDOW
AND NOT  WS_EX_APPWINDOW);
  Application.CreateForm(TForm1, Form1);
  Application.Run;

This will prevent your main form from showing in the Taskbar. Of course, you
should put the code in your Formcreate...
to put the icon into the Tray, as described in a reply to your question.
The thing here is that your application creates another window, aside from
(and before) your main window. This window class is used for displaying icon
in the Taskbar. Note that your window has its title in the caption bar,
whereas its icon in the taskbar has the title of your executable.
